@@ -108,6 +108,10 @@ class StyleguideComponent(dict):
     def link(self):
         return self._data['link']
 
+    @property
+    def template(self):
+        return self._data['template']
+
     @property
     def doc(self):
         return self._data['doc']
